@@ -6,9 +6,8 @@ venue_DB = 'enterprise'
 SITE_ID=1
 ADMINS = ()
 MANAGERS = ADMINS
-USE_TZ = False
-TIME_ZONE = None
-#TIME_ZONE = 'America/Los_Angeles'
+USE_TZ = True
+TIME_ZONE = 'America/Los_Angeles'
 LANGUAGE_CODE = 'en-us'
 USE_I18N = True
 SECRET_KEY = '0p3ffc)q#f-4rv23&amp;yqp-f_p04p(lp(i!&amp;wljvvnk690=!0wo$'
