@@ -112,6 +112,8 @@ class Venue():
 
 
 
+
+
     def __unicode__(self):
         s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
         return s
@@ -135,6 +137,20 @@ def copy_venue_skel(venue_path):
         raise
     return True
 
+def create_venue_uwsgi_file(VENUE_ROOT, VENUE_NAME):
+    """create the uwsgi ini file for a (usually) new Venue.
+    Reads backstage/config/uwsgi.venue.ini.src
+    """
+    srcfile = os.path.join(os.path.dirname(backstage.__file__), 'conf/uwsgi.venue.ini.src')
+    with open(srcfile, 'r') as f:
+        srcdata = f.read()
+    outfile = os.path.join(VENUE_ROOT, 'uwsgi.ini')
+    o = open(outfile, 'w')
+    o.write(srcdata.format(VENUE_ROOT=VENUE_ROOT))
+    o.close()
+    return
+
+
 def new_venue(venue_name, venue_path, source_ini_file = None):
         """create a new backstage venue with the given name and located at the specified path"""
         venue_path = os.path.abspath(os.path.join(venue_path, venue_name))
@@ -151,16 +167,6 @@ def new_venue(venue_name, venue_path, source_ini_file = None):
             err = 'ERROR with init file'
             print err
             raise
-        try:
-            if source_ini_file is not None:
-                pass  #try to copy the file
-            fh=open(os.path.join(venue_path, 'backstage.ini'), 'w')
-            fh.write('[backstage]\n')
-            fh.close()
-        except:
-            print 'Error with INI file'
-            raise
-
         try:
             copy_venue_skel(venue_path)
         except:
@@ -168,6 +174,12 @@ def new_venue(venue_name, venue_path, source_ini_file = None):
             print s
             raise
 
+        try:
+            create_venue_uwsgi_file(venue_path, venue_name)
+        except:
+            s = 'Error in create_venue_wsgi_file'
+            print s
+            raise
 
 
         try:
